
if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database /usr/share/applications >/dev/null 2>&1
fi

( cd usr/lib ; rm -rf libmbox.so.4 )
( cd usr/lib ; ln -sf libmbox.so.4.4.0 libmbox.so.4 )
( cd usr/lib ; rm -rf libakonadi-xml.so )
( cd usr/lib ; ln -sf libakonadi-xml.so.4 libakonadi-xml.so )
( cd usr/lib ; rm -rf libmbox.so )
( cd usr/lib ; ln -sf libmbox.so.4 libmbox.so )
( cd usr/lib ; rm -rf libkdepim-copy.so )
( cd usr/lib ; ln -sf libkdepim-copy.so.4 libkdepim-copy.so )
( cd usr/lib ; rm -rf libakonadi-xml.so.4 )
( cd usr/lib ; ln -sf libakonadi-xml.so.4.4.0 libakonadi-xml.so.4 )
( cd usr/lib ; rm -rf libkdepim-copy.so.4 )
( cd usr/lib ; ln -sf libkdepim-copy.so.4.4.0 libkdepim-copy.so.4 )
( cd usr/lib ; rm -rf libmaildir.so )
( cd usr/lib ; ln -sf libmaildir.so.4 libmaildir.so )
( cd usr/lib ; rm -rf libmaildir.so.4 )
( cd usr/lib ; ln -sf libmaildir.so.4.4.0 libmaildir.so.4 )
